@@ -5,7 +5,7 @@ use std::path::PathBuf;
 
 use crate::buildpack::Buildpack;
 use crate::data::buildpack::StackId;
-use crate::{data::build_plan::BuildPlan, data::buildpack::BuildpackToml};
+use crate::{data::build_plan::BuildPlan, data::buildpack::SingleBuildpackDescriptor};
 
 /// Context for the detect phase execution.
 pub struct DetectContext<B: Buildpack + ?Sized> {
@@ -13,7 +13,7 @@ pub struct DetectContext<B: Buildpack + ?Sized> {
     pub buildpack_dir: PathBuf,
     pub stack_id: StackId,
     pub platform: B::Platform,
-    pub buildpack_descriptor: BuildpackToml<B::Metadata>,
+    pub buildpack_descriptor: SingleBuildpackDescriptor<B::Metadata>,
 }
 
 /// Describes the result of the detect phase.
@@ -46,10 +46,12 @@ pub(crate) enum InnerDetectResult {
 pub struct DetectResultBuilder;
 
 impl DetectResultBuilder {
+    #[must_use]
     pub fn pass() -> PassDetectResultBuilder {
         PassDetectResultBuilder { build_plan: None }
     }
 
+    #[must_use]
     pub fn fail() -> FailDetectResultBuilder {
         FailDetectResultBuilder {}
     }
@@ -73,12 +75,14 @@ impl PassDetectResultBuilder {
         Ok(self.build_unwrapped())
     }
 
+    #[must_use]
     pub fn build_unwrapped(self) -> DetectResult {
         DetectResult(InnerDetectResult::Pass {
             build_plan: self.build_plan,
         })
     }
 
+    #[must_use]
     pub fn build_plan(mut self, build_plan: BuildPlan) -> Self {
         self.build_plan = Some(build_plan);
         self
@@ -102,6 +106,7 @@ impl FailDetectResultBuilder {
     }
 
     #[allow(clippy::unused_self)]
+    #[must_use]
     pub fn build_unwrapped(self) -> DetectResult {
         DetectResult(InnerDetectResult::Fail)
     }
