@@ -40,15 +40,9 @@ pub(crate) fn handle_layer<B: Buildpack + ?Sized, L: Layer<Buildpack = B>>(
                         &layer_data.name,
                         &layer_data.env,
                         &LayerContentMetadata {
-                            // We cannot copy the types from layer_data due to an issue with the current
-                            // libcnb implementation. The types will be missing in the TOML file on disk
-                            // but if they're not there, their default values will be used when
-                            // deserializing. Issue: https://github.com/Malax/libcnb.rs/issues/146
-                            //
-                            // Even if the deserialization of LayerContentMetadata is fixed, it would
-                            // not contain the layer types as they're not restored by the CNB lifecycle.
+                            // We cannot copy the types from layer_data since they're not restored by the CNB lifecycle.
                             // We must call layer.types here to get the correct types for the layer.
-                            types: layer.types(),
+                            types: Some(layer.types()),
                             metadata: layer_data.content_metadata.metadata,
                         },
                     )?;
@@ -120,7 +114,7 @@ fn handle_create_layer<B: Buildpack + ?Sized, L: Layer<Buildpack = B>>(
         layer_name,
         &layer_result.env.unwrap_or_default(),
         &LayerContentMetadata {
-            types: layer.types(),
+            types: Some(layer.types()),
             metadata: layer_result.metadata,
         },
     )?;
@@ -144,7 +138,7 @@ fn handle_update_layer<B: Buildpack + ?Sized, L: Layer<Buildpack = B>>(
         &layer_data.name,
         &layer_result.env.unwrap_or_default(),
         &LayerContentMetadata {
-            types: layer.types(),
+            types: Some(layer.types()),
             metadata: layer_result.metadata,
         },
     )?;
@@ -304,8 +298,8 @@ mod tests {
     use crate::data::layer_content_metadata::{LayerContentMetadata, LayerTypes};
     use crate::data::layer_name;
     use crate::generic::GenericMetadata;
-    use crate::layer_env::{ModificationBehavior, TargetLifecycle};
-    use crate::{read_toml_file, Env};
+    use crate::layer_env::{ModificationBehavior, Scope};
+    use crate::read_toml_file;
     use serde::Deserialize;
     use std::ffi::OsString;
     use std::fs;
@@ -381,17 +375,17 @@ mod tests {
             &layers_dir,
             &layer_name,
             &LayerEnv::new().chainable_insert(
-                TargetLifecycle::All,
+                Scope::All,
                 ModificationBehavior::Default,
                 "ENV_VAR",
                 "ENV_VAR_VALUE",
             ),
             &LayerContentMetadata {
-                types: LayerTypes {
+                types: Some(LayerTypes {
                     launch: true,
                     build: true,
                     cache: false,
-                },
+                }),
                 metadata: GenericMetadata::default(),
             },
         )
@@ -409,11 +403,11 @@ mod tests {
 
         assert_eq!(
             layer_content_metadata.types,
-            LayerTypes {
+            Some(LayerTypes {
                 launch: true,
                 build: true,
                 cache: false
-            }
+            })
         );
     }
 
@@ -429,23 +423,23 @@ mod tests {
             &layer_name,
             &LayerEnv::new()
                 .chainable_insert(
-                    TargetLifecycle::All,
+                    Scope::All,
                     ModificationBehavior::Default,
                     "ENV_VAR",
                     "INITIAL_ENV_VAR_VALUE",
                 )
                 .chainable_insert(
-                    TargetLifecycle::All,
+                    Scope::All,
                     ModificationBehavior::Default,
                     "SOME_OTHER_ENV_VAR",
                     "SOME_OTHER_ENV_VAR_VALUE",
                 ),
             &LayerContentMetadata {
-                types: LayerTypes {
+                types: Some(LayerTypes {
                     launch: false,
                     build: false,
                     cache: true,
-                },
+                }),
                 metadata: GenericMetadata::default(),
             },
         )
@@ -457,17 +451,17 @@ mod tests {
             &layers_dir,
             &layer_name,
             &LayerEnv::new().chainable_insert(
-                TargetLifecycle::All,
+                Scope::All,
                 ModificationBehavior::Default,
                 "ENV_VAR",
                 "NEW_ENV_VAR_VALUE",
             ),
             &LayerContentMetadata {
-                types: LayerTypes {
+                types: Some(LayerTypes {
                     launch: false,
                     build: false,
                     cache: true,
-                },
+                }),
                 metadata: GenericMetadata::default(),
             },
         )
@@ -492,11 +486,11 @@ mod tests {
 
         assert_eq!(
             layer_content_metadata.types,
-            LayerTypes {
+            Some(LayerTypes {
                 launch: false,
                 build: false,
                 cache: true
-            }
+            })
         );
     }
 
@@ -546,11 +540,11 @@ mod tests {
 
         assert_eq!(
             layer_data.content_metadata.types,
-            LayerTypes {
+            Some(LayerTypes {
                 launch: true,
                 build: false,
                 cache: true
-            }
+            })
         );
 
         assert_eq!(
@@ -563,7 +557,7 @@ mod tests {
             }
         );
 
-        let applied_layer_env = layer_data.env.apply(TargetLifecycle::Build, &Env::new());
+        let applied_layer_env = layer_data.env.apply_to_empty(Scope::Build);
         assert_eq!(
             applied_layer_env.get("PATH"),
             Some(layer_dir.join("bin").into())
@@ -649,7 +643,13 @@ mod tests {
 
         match super::read_layer::<GenericMetadata, _>(&layers_dir, &layer_name) {
             Ok(Some(layer_data)) => {
-                assert_eq!(layer_data.content_metadata, LayerContentMetadata::default());
+                assert_eq!(
+                    layer_data.content_metadata,
+                    LayerContentMetadata {
+                        types: None,
+                        metadata: None
+                    }
+                );
             }
             _ => panic!("Expected Ok(Some(_)!"),
         }
