@@ -19,9 +19,9 @@ use crate::layer::{
     handle_layer, ExistingLayerStrategy, Layer, LayerData, LayerResult, LayerResultBuilder,
     MetadataMigration,
 };
-use crate::layer_env::{LayerEnv, ModificationBehavior, TargetLifecycle};
+use crate::layer_env::{LayerEnv, ModificationBehavior, Scope};
 use crate::{read_toml_file, Buildpack, Env, LIBCNB_SUPPORTED_BUILDPACK_API};
-use libcnb_data::buildpack::{BuildpackToml, Stack};
+use libcnb_data::buildpack::{BuildpackVersion, SingleBuildpackDescriptor, Stack};
 use libcnb_data::buildpack_plan::BuildpackPlan;
 use libcnb_data::layer::LayerName;
 use libcnb_data::layer_content_metadata::LayerContentMetadata;
@@ -146,11 +146,11 @@ fn create() {
 
     // Assert layer content metadata, returned and on disk
     let expected_content_layer_metadata = LayerContentMetadata {
-        types: LayerTypes {
+        types: Some(LayerTypes {
             launch: TEST_LAYER_LAUNCH,
             build: TEST_LAYER_BUILD,
             cache: TEST_LAYER_CACHE,
-        },
+        }),
         metadata: TestLayerMetadata {
             version: metadata_version_string,
         },
@@ -215,11 +215,11 @@ fn create_then_update() {
 
     // Assert layer content metadata, returned and on disk
     let expected_content_layer_metadata = LayerContentMetadata {
-        types: LayerTypes {
+        types: Some(LayerTypes {
             launch: TEST_LAYER_LAUNCH,
             build: TEST_LAYER_BUILD,
             cache: TEST_LAYER_CACHE,
-        },
+        }),
         metadata: TestLayerMetadata {
             version: metadata_version_string,
         },
@@ -307,11 +307,11 @@ fn create_then_recreate() {
 
     // Assert layer content metadata, returned and on disk
     let expected_content_layer_metadata = LayerContentMetadata {
-        types: LayerTypes {
+        types: Some(LayerTypes {
             launch: TEST_LAYER_LAUNCH,
             build: TEST_LAYER_BUILD,
             cache: TEST_LAYER_CACHE,
-        },
+        }),
         metadata: TestLayerMetadata {
             version: recreated_metadata_version_string,
         },
@@ -401,11 +401,11 @@ fn create_then_keep() {
 
     // Assert layer content metadata, returned and on disk
     let expected_content_layer_metadata = LayerContentMetadata {
-        types: LayerTypes {
+        types: Some(LayerTypes {
             launch: TEST_LAYER_LAUNCH,
             build: TEST_LAYER_BUILD,
             cache: TEST_LAYER_CACHE,
-        },
+        }),
         metadata: TestLayerMetadata {
             version: metadata_version_string,
         },
@@ -491,11 +491,11 @@ v = "3.2.1"
 
     // Assert layer content metadata, returned and on disk
     let expected_content_layer_metadata = LayerContentMetadata {
-        types: LayerTypes {
+        types: Some(LayerTypes {
             launch: TEST_LAYER_LAUNCH,
             build: TEST_LAYER_BUILD,
             cache: TEST_LAYER_CACHE,
-        },
+        }),
         metadata: TestLayerMetadata {
             // This is the version from a hand-rolled, incompatible metadata TOML file and
             // intentionally not metadata_version_string.
@@ -581,11 +581,11 @@ versi_on = "3.2.1"
 
     // Assert layer content metadata, returned and on disk
     let expected_content_layer_metadata = LayerContentMetadata {
-        types: LayerTypes {
+        types: Some(LayerTypes {
             launch: TEST_LAYER_LAUNCH,
             build: TEST_LAYER_BUILD,
             cache: TEST_LAYER_CACHE,
-        },
+        }),
         metadata: TestLayerMetadata {
             version: metadata_version_string,
         },
@@ -708,7 +708,7 @@ fn write_layer_env() {
     let layer_name = random_layer_name();
     let metadata_version_string = String::from("1.0.0");
     let layer_env = LayerEnv::new().chainable_insert(
-        TargetLifecycle::All,
+        Scope::All,
         ModificationBehavior::Append,
         "RANDOM",
         "4", // chosen by fair dice roll, guaranteed to be random.
@@ -780,13 +780,13 @@ fn default_layer_method_implementations() {
         name: layer_name,
         path: PathBuf::default(),
         env: LayerEnv::new().chainable_insert(
-            TargetLifecycle::All,
+            Scope::All,
             ModificationBehavior::Default,
             "FOO",
             "bar",
         ),
         content_metadata: LayerContentMetadata {
-            types: LayerTypes::default(),
+            types: Some(LayerTypes::default()),
             metadata: simple_layer_metadata.clone(),
         },
     };
@@ -871,7 +871,7 @@ fn layer_env_read_write() {
 
     let layer = LayerDataTestLayer {
         expected_layer_env: LayerEnv::new().chainable_insert(
-            TargetLifecycle::All,
+            Scope::All,
             ModificationBehavior::Override,
             "FOO",
             "bar",
@@ -903,12 +903,12 @@ fn build_context(temp_dir: &TempDir) -> BuildContext<TestBuildpack> {
         stack_id: stack_id!("heroku-20"),
         platform: GenericPlatform::new(Env::new()),
         buildpack_plan: BuildpackPlan { entries: vec![] },
-        buildpack_descriptor: BuildpackToml {
+        buildpack_descriptor: SingleBuildpackDescriptor {
             api: LIBCNB_SUPPORTED_BUILDPACK_API,
             buildpack: crate::data::buildpack::Buildpack {
                 id: buildpack_id!("libcnb/test"),
                 name: None,
-                version: "1.0.0".parse().unwrap(),
+                version: BuildpackVersion::new(1, 0, 0),
                 homepage: None,
                 clear_env: true,
                 description: None,
@@ -916,7 +916,6 @@ fn build_context(temp_dir: &TempDir) -> BuildContext<TestBuildpack> {
                 licenses: vec![],
             },
             stacks: vec![Stack::Any],
-            order: vec![],
             metadata: GenericMetadata::default(),
         },
     }
