@@ -36,18 +36,18 @@ use crate::Env;
 ///
 /// To apply a `LayerEnv` delta to a given `Env`, use [`LayerEnv::apply`] like so:
 ///```
-/// use libcnb::layer_env::{LayerEnv, TargetLifecycle, ModificationBehavior};
+/// use libcnb::layer_env::{LayerEnv, Scope, ModificationBehavior};
 /// use libcnb::Env;
 ///
 /// let mut layer_env = LayerEnv::new();
-/// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Append, "VAR", "bar");
-/// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Default, "VAR2", "default");
+/// layer_env.insert(Scope::All, ModificationBehavior::Append, "VAR", "bar");
+/// layer_env.insert(Scope::All, ModificationBehavior::Default, "VAR2", "default");
 ///
 /// let mut env = Env::new();
 /// env.insert("VAR", "foo");
 /// env.insert("VAR2", "previous-value");
 ///
-/// let modified_env = layer_env.apply(TargetLifecycle::Build, &env);
+/// let modified_env = layer_env.apply(Scope::Build, &env);
 /// assert_eq!(modified_env.get("VAR").unwrap(), "foobar");
 /// assert_eq!(modified_env.get("VAR2").unwrap(), "previous-value");
 /// ```
@@ -63,7 +63,7 @@ use crate::Env;
 /// libcnb supports these, including all precedence and lifecycle rules, when a `LayerEnv` is read
 /// from disk:
 ///```
-/// use libcnb::layer_env::{LayerEnv, TargetLifecycle};
+/// use libcnb::layer_env::{LayerEnv, Scope};
 /// use tempfile::tempdir;
 /// use libcnb::Env;
 /// use std::fs;
@@ -75,12 +75,10 @@ use crate::Env;
 /// fs::create_dir_all(layer_dir.join("include")).unwrap();
 ///
 /// let layer_env = LayerEnv::read_from_layer_dir(&layer_dir).unwrap();
+/// let env = layer_env.apply_to_empty(Scope::Launch);
 ///
-/// let env = Env::new();
-/// let modified_env = layer_env.apply(TargetLifecycle::Launch, &env);
-///
-/// assert_eq!(modified_env.get("PATH").unwrap(), layer_dir.join("bin"));
-/// assert_eq!(modified_env.get("CPATH"), None); // None, because CPATH is only added during build
+/// assert_eq!(env.get("PATH").unwrap(), layer_dir.join("bin"));
+/// assert_eq!(env.get("CPATH"), None); // None, because CPATH is only added during build
 /// ```
 #[derive(Eq, PartialEq, Debug, Clone)]
 pub struct LayerEnv {
@@ -104,15 +102,16 @@ impl LayerEnv {
     ///
     /// # Example:
     /// ```
-    /// use libcnb::layer_env::{LayerEnv, TargetLifecycle};
+    /// use libcnb::layer_env::{LayerEnv, Scope};
     /// use libcnb::Env;
     ///
     /// let layer_env = LayerEnv::new();
     /// let mut env = Env::new();
     ///
-    /// let modified_env = layer_env.apply(TargetLifecycle::Build, &env);
+    /// let modified_env = layer_env.apply(Scope::Build, &env);
     /// assert_eq!(env, modified_env);
     /// ```
+    #[must_use]
     pub fn new() -> Self {
         Self {
             all: LayerEnvDelta::new(),
@@ -124,31 +123,34 @@ impl LayerEnv {
         }
     }
 
-    /// Applies this [`LayerEnv`] to the given [`Env`] for the given [target lifecycle](TargetLifecycle).
+    /// Applies this [`LayerEnv`] to the given [`Env`] for the given [`Scope`].
+    ///
+    /// For applying to an empty [`Env`], see [`apply_to_empty`](Self::apply_to_empty).
     ///
     /// # Example:
     ///```
-    /// use libcnb::layer_env::{LayerEnv, TargetLifecycle, ModificationBehavior};
+    /// use libcnb::layer_env::{LayerEnv, Scope, ModificationBehavior};
     /// use libcnb::Env;
     ///
     /// let mut layer_env = LayerEnv::new();
-    /// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Append, "VAR", "bar");
-    /// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Default, "VAR2", "default");
+    /// layer_env.insert(Scope::All, ModificationBehavior::Append, "VAR", "bar");
+    /// layer_env.insert(Scope::All, ModificationBehavior::Default, "VAR2", "default");
     ///
     /// let mut env = Env::new();
     /// env.insert("VAR", "foo");
     /// env.insert("VAR2", "previous-value");
     ///
-    /// let modified_env = layer_env.apply(TargetLifecycle::Build, &env);
+    /// let modified_env = layer_env.apply(Scope::Build, &env);
     /// assert_eq!(modified_env.get("VAR").unwrap(), "foobar");
     /// assert_eq!(modified_env.get("VAR2").unwrap(), "previous-value");
     /// ```
-    pub fn apply(&self, target: TargetLifecycle, env: &Env) -> Env {
-        let deltas = match target {
-            TargetLifecycle::All => vec![&self.all],
-            TargetLifecycle::Build => vec![&self.all, &self.build, &self.layer_paths_build],
-            TargetLifecycle::Launch => vec![&self.all, &self.launch, &self.layer_paths_launch],
-            TargetLifecycle::Process(process) => {
+    #[must_use]
+    pub fn apply(&self, scope: Scope, env: &Env) -> Env {
+        let deltas = match scope {
+            Scope::All => vec![&self.all],
+            Scope::Build => vec![&self.all, &self.build, &self.layer_paths_build],
+            Scope::Launch => vec![&self.all, &self.launch, &self.layer_paths_launch],
+            Scope::Process(process) => {
                 let mut process_deltas = vec![&self.all];
                 if let Some(process_specific_delta) = self.process.get(&process) {
                     process_deltas.push(process_specific_delta);
@@ -163,48 +165,53 @@ impl LayerEnv {
             .fold(env.clone(), |env, delta| delta.apply(&env))
     }
 
+    /// Applies this [`LayerEnv`] to an empty [`Env`] for the given [`Scope`].
+    ///
+    /// For applying to an existing [`Env`], see [`apply`](Self::apply).
+    #[must_use]
+    pub fn apply_to_empty(&self, scope: Scope) -> Env {
+        self.apply(scope, &Env::new())
+    }
+
     /// Insert a new entry into this `LayerEnv`.
     ///
-    /// Should there already be an entry for the same target lifecycle, modification behavior and
+    /// Should there already be an entry for the same scope, modification behavior and
     /// name, it will be updated with the new given value.
     ///
     /// # Example:
     /// ```
-    /// use libcnb::layer_env::{LayerEnv, TargetLifecycle, ModificationBehavior};
+    /// use libcnb::layer_env::{LayerEnv, Scope, ModificationBehavior};
     /// use libcnb::Env;
     ///
     /// let mut layer_env = LayerEnv::new();
-    /// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Default, "VAR", "hello");
+    /// layer_env.insert(Scope::All, ModificationBehavior::Default, "VAR", "hello");
     /// // "foo" will be overridden by "bar" here:
-    /// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Append, "VAR2", "foo");
-    /// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Append, "VAR2", "bar");
+    /// layer_env.insert(Scope::All, ModificationBehavior::Append, "VAR2", "foo");
+    /// layer_env.insert(Scope::All, ModificationBehavior::Append, "VAR2", "bar");
     ///
-    /// let mut env = Env::new();
-    /// let modified_env = layer_env.apply(TargetLifecycle::Build, &env);
+    /// let env = layer_env.apply_to_empty(Scope::Build);
     ///
-    /// assert_eq!(modified_env.get("VAR").unwrap(), "hello");
-    /// assert_eq!(modified_env.get("VAR2").unwrap(), "bar");
+    /// assert_eq!(env.get("VAR").unwrap(), "hello");
+    /// assert_eq!(env.get("VAR2").unwrap(), "bar");
     /// ```
     ///
     /// See [`LayerEnv::chainable_insert`] that allows easy creation of inline `LayerEnv` values
     /// without intermediate variables.
     pub fn insert(
         &mut self,
-        target: TargetLifecycle,
+        scope: Scope,
         modification_behavior: ModificationBehavior,
         name: impl Into<OsString>,
         value: impl Into<OsString>,
     ) {
-        let target_delta = match target {
-            TargetLifecycle::All => &mut self.all,
-            TargetLifecycle::Build => &mut self.build,
-            TargetLifecycle::Launch => &mut self.launch,
-            TargetLifecycle::Process(process_type_name) => {
-                match self.process.entry(process_type_name) {
-                    Entry::Occupied(entry) => entry.into_mut(),
-                    Entry::Vacant(entry) => entry.insert(LayerEnvDelta::new()),
-                }
-            }
+        let target_delta = match scope {
+            Scope::All => &mut self.all,
+            Scope::Build => &mut self.build,
+            Scope::Launch => &mut self.launch,
+            Scope::Process(process_type_name) => match self.process.entry(process_type_name) {
+                Entry::Occupied(entry) => entry.into_mut(),
+                Entry::Vacant(entry) => entry.insert(LayerEnvDelta::new()),
+            },
         };
 
         target_delta.insert(modification_behavior, name, value);
@@ -217,40 +224,40 @@ impl LayerEnv {
     ///
     /// # Example:
     /// ```
-    /// use libcnb::layer_env::{LayerEnv, ModificationBehavior, TargetLifecycle};
+    /// use libcnb::layer_env::{LayerEnv, ModificationBehavior, Scope};
     /// use libcnb::Env;
     ///
     /// fn something_that_needs_layer_env(layer_env: LayerEnv) {
-    ///     let mut env = Env::new();
-    ///     let modified_env = layer_env.apply(TargetLifecycle::Build, &env);
-    ///     assert_eq!(modified_env.get("VAR").unwrap(), "hello");
-    ///     assert_eq!(modified_env.get("VAR2").unwrap(), "bar");
+    ///     let env = layer_env.apply_to_empty(Scope::Build);
+    ///     assert_eq!(env.get("VAR").unwrap(), "hello");
+    ///     assert_eq!(env.get("VAR2").unwrap(), "bar");
     /// }
     ///
     /// something_that_needs_layer_env(
     ///     LayerEnv::new()
     ///         .chainable_insert(
-    ///             TargetLifecycle::All,
+    ///             Scope::All,
     ///             ModificationBehavior::Default,
     ///             "VAR",
     ///             "hello",
     ///         )
     ///         .chainable_insert(
-    ///             TargetLifecycle::All,
+    ///             Scope::All,
     ///             ModificationBehavior::Append,
     ///             "VAR2",
     ///             "bar",
     ///         ),
     /// );
     /// ```
+    #[must_use]
     pub fn chainable_insert(
         mut self,
-        target: TargetLifecycle,
+        scope: Scope,
         modification_behavior: ModificationBehavior,
         name: impl Into<OsString>,
         value: impl Into<OsString>,
     ) -> Self {
-        self.insert(target, modification_behavior, name, value);
+        self.insert(scope, modification_behavior, name, value);
         self
     }
 
@@ -264,7 +271,7 @@ impl LayerEnv {
     ///
     /// # Example:
     ///```
-    /// use libcnb::layer_env::{LayerEnv, TargetLifecycle};
+    /// use libcnb::layer_env::{LayerEnv, Scope};
     /// use tempfile::tempdir;
     /// use libcnb::Env;
     /// use std::fs;
@@ -279,12 +286,10 @@ impl LayerEnv {
     /// fs::write(layer_env_dir.join("ZERO_WING.default"), "ALL_YOUR_BASE_ARE_BELONG_TO_US").unwrap();
     ///
     /// let layer_env = LayerEnv::read_from_layer_dir(&layer_dir).unwrap();
+    /// let env = layer_env.apply_to_empty(Scope::Launch);
     ///
-    /// let env = Env::new();
-    /// let modified_env = layer_env.apply(TargetLifecycle::Launch, &env);
-    ///
-    /// assert_eq!(modified_env.get("PATH").unwrap(), layer_dir.join("bin"));
-    /// assert_eq!(modified_env.get("ZERO_WING").unwrap(), "ALL_YOUR_BASE_ARE_BELONG_TO_US");
+    /// assert_eq!(env.get("PATH").unwrap(), layer_dir.join("bin"));
+    /// assert_eq!(env.get("ZERO_WING").unwrap(), "ALL_YOUR_BASE_ARE_BELONG_TO_US");
     /// ```
     pub fn read_from_layer_dir(layer_dir: impl AsRef<Path>) -> Result<Self, std::io::Error> {
         let mut result_layer_env = Self::new();
@@ -295,21 +300,21 @@ impl LayerEnv {
         let pkgconfig_path = layer_dir.as_ref().join("pkgconfig");
 
         let layer_path_specs = vec![
-            ("PATH", TargetLifecycle::Build, &bin_path),
-            ("LIBRARY_PATH", TargetLifecycle::Build, &lib_path),
-            ("LD_LIBRARY_PATH", TargetLifecycle::Build, &lib_path),
-            ("CPATH", TargetLifecycle::Build, &include_path),
-            ("PKG_CONFIG_PATH", TargetLifecycle::Build, &pkgconfig_path),
-            ("PATH", TargetLifecycle::Launch, &bin_path),
-            ("LD_LIBRARY_PATH", TargetLifecycle::Launch, &lib_path),
+            ("PATH", Scope::Build, &bin_path),
+            ("LIBRARY_PATH", Scope::Build, &lib_path),
+            ("LD_LIBRARY_PATH", Scope::Build, &lib_path),
+            ("CPATH", Scope::Build, &include_path),
+            ("PKG_CONFIG_PATH", Scope::Build, &pkgconfig_path),
+            ("PATH", Scope::Launch, &bin_path),
+            ("LD_LIBRARY_PATH", Scope::Launch, &lib_path),
         ];
 
-        for (name, target_lifecycle, path) in layer_path_specs {
+        for (name, scope, path) in layer_path_specs {
             if path.is_dir() {
-                let target_delta = match target_lifecycle {
-                    TargetLifecycle::Build => &mut result_layer_env.layer_paths_build,
-                    TargetLifecycle::Launch => &mut result_layer_env.layer_paths_launch,
-                    _ => unreachable!("Unexpected TargetLifecycle in read_from_layer_dir implementation. This is a libcnb implementation error!"),
+                let target_delta = match scope {
+                    Scope::Build => &mut result_layer_env.layer_paths_build,
+                    Scope::Launch => &mut result_layer_env.layer_paths_launch,
+                    _ => unreachable!("Unexpected Scope in read_from_layer_dir implementation. This is a libcnb implementation error!"),
                 };
 
                 target_delta.insert(ModificationBehavior::Prepend, &name, &path);
@@ -345,13 +350,13 @@ impl LayerEnv {
     ///
     /// Example:
     /// ```
-    /// use libcnb::layer_env::{LayerEnv, TargetLifecycle, ModificationBehavior};
+    /// use libcnb::layer_env::{LayerEnv, Scope, ModificationBehavior};
     /// use tempfile::tempdir;
     /// use std::fs;
     ///
     /// let mut layer_env = LayerEnv::new();
-    /// layer_env.insert(TargetLifecycle::Build, ModificationBehavior::Default, "FOO", "bar");
-    /// layer_env.insert(TargetLifecycle::All, ModificationBehavior::Append, "PATH", "some-path");
+    /// layer_env.insert(Scope::Build, ModificationBehavior::Default, "FOO", "bar");
+    /// layer_env.insert(Scope::All, ModificationBehavior::Append, "PATH", "some-path");
     ///
     /// let mut temp_dir = tempdir().unwrap();
     /// layer_env.write_to_layer_dir(&temp_dir).unwrap();
@@ -418,9 +423,9 @@ impl PartialOrd for ModificationBehavior {
     }
 }
 
-/// Target lifecycle for an environment variable modification.
+/// The scope of an environment variable modification.
 #[derive(Eq, PartialEq, Debug)]
-pub enum TargetLifecycle {
+pub enum Scope {
     All,
     Build,
     Launch,
@@ -595,7 +600,7 @@ mod tests {
 
     use tempfile::tempdir;
 
-    use crate::layer_env::{Env, LayerEnv, ModificationBehavior, TargetLifecycle};
+    use crate::layer_env::{Env, LayerEnv, ModificationBehavior, Scope};
 
     use super::LayerEnvDelta;
 
@@ -718,7 +723,7 @@ mod tests {
         original_env.insert("LIBRARY_PATH", "some-library");
 
         let layer_env = LayerEnv::read_from_layer_dir(temp_dir.path()).unwrap();
-        let modified_env = layer_env.apply(TargetLifecycle::Build, &original_env);
+        let modified_env = layer_env.apply(Scope::Build, &original_env);
 
         assert_eq!(
             vec![
@@ -776,34 +781,34 @@ mod tests {
     fn layer_env_insert() {
         let mut layer_env = LayerEnv::new();
         layer_env.insert(
-            TargetLifecycle::Build,
+            Scope::Build,
             ModificationBehavior::Append,
             "MAVEN_OPTS",
             "-Dskip.tests=true",
         );
 
         layer_env.insert(
-            TargetLifecycle::All,
+            Scope::All,
             ModificationBehavior::Override,
             "JAVA_TOOL_OPTIONS",
             "-Xmx1G",
         );
 
         layer_env.insert(
-            TargetLifecycle::Build,
+            Scope::Build,
             ModificationBehavior::Override,
             "JAVA_TOOL_OPTIONS",
             "-Xmx2G",
         );
 
         layer_env.insert(
-            TargetLifecycle::Launch,
+            Scope::Launch,
             ModificationBehavior::Append,
             "JAVA_TOOL_OPTIONS",
             "-XX:+UseSerialGC",
         );
 
-        let result_env = layer_env.apply(TargetLifecycle::Build, &Env::new());
+        let result_env = layer_env.apply_to_empty(Scope::Build);
         assert_eq!(
             vec![
                 ("JAVA_TOOL_OPTIONS", "-Xmx2G"),
@@ -875,17 +880,13 @@ mod tests {
         fs::create_dir_all(layer_dir.join("pkgconfig")).unwrap();
 
         let layer_env = LayerEnv::read_from_layer_dir(&layer_dir).unwrap();
-        let env = Env::new();
 
-        let modified_env = layer_env.apply(TargetLifecycle::Launch, &env);
-        assert_eq!(modified_env.get("PATH").unwrap(), layer_dir.join("bin"));
-        assert_eq!(
-            modified_env.get("LD_LIBRARY_PATH").unwrap(),
-            layer_dir.join("lib")
-        );
-        assert_eq!(modified_env.get("LIBRARY_PATH"), None);
-        assert_eq!(modified_env.get("CPATH"), None);
-        assert_eq!(modified_env.get("PKG_CONFIG_PATH"), None);
+        let env = layer_env.apply_to_empty(Scope::Launch);
+        assert_eq!(env.get("PATH").unwrap(), layer_dir.join("bin"));
+        assert_eq!(env.get("LD_LIBRARY_PATH").unwrap(), layer_dir.join("lib"));
+        assert_eq!(env.get("LIBRARY_PATH"), None);
+        assert_eq!(env.get("CPATH"), None);
+        assert_eq!(env.get("PKG_CONFIG_PATH"), None);
     }
 
     #[test]
@@ -900,24 +901,14 @@ mod tests {
         fs::create_dir_all(layer_dir.join("pkgconfig")).unwrap();
 
         let layer_env = LayerEnv::read_from_layer_dir(&layer_dir).unwrap();
-        let env = Env::new();
 
-        let modified_env = layer_env.apply(TargetLifecycle::Build, &env);
-        assert_eq!(modified_env.get("PATH").unwrap(), layer_dir.join("bin"));
+        let env = layer_env.apply_to_empty(Scope::Build);
+        assert_eq!(env.get("PATH").unwrap(), layer_dir.join("bin"));
+        assert_eq!(env.get("LD_LIBRARY_PATH").unwrap(), layer_dir.join("lib"));
+        assert_eq!(env.get("LIBRARY_PATH").unwrap(), layer_dir.join("lib"));
+        assert_eq!(env.get("CPATH").unwrap(), layer_dir.join("include"));
         assert_eq!(
-            modified_env.get("LD_LIBRARY_PATH").unwrap(),
-            layer_dir.join("lib")
-        );
-        assert_eq!(
-            modified_env.get("LIBRARY_PATH").unwrap(),
-            layer_dir.join("lib")
-        );
-        assert_eq!(
-            modified_env.get("CPATH").unwrap(),
-            layer_dir.join("include")
-        );
-        assert_eq!(
-            modified_env.get("PKG_CONFIG_PATH").unwrap(),
+            env.get("PKG_CONFIG_PATH").unwrap(),
             layer_dir.join("pkgconfig")
         );
     }
